@@ -14,7 +14,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include "config.h"
+#include "eztrace_config.h"
 
 #include <stddef.h>
 #include <stdint.h>
@@ -41,6 +41,27 @@
 void eztrace_start();
 /* stop recording events and write the trace to the disk */
 void eztrace_stop();
+/* start eztrace but only record some event (thread creation, mpi_init, mpi communicators creation..)*/
+void eztrace_silent_start();
+
+/* pre-defined color for manual instrumentation*/
+enum ezt_color {
+  EZTRACE_RED,
+  EZTRACE_BLUE,
+  EZTRACE_GREEN,
+  EZTRACE_YELLOW,
+  EZTRACE_PINK
+};
+
+/* Stop the recording of events  */
+void eztrace_pause();
+/* Restart the recording of events*/
+void eztrace_resume();
+/* Manually add one event and choose one color for the display */
+void eztrace_enter_event(char *, enum ezt_color);
+/* Set the end of the event */
+void eztrace_leave_event();
+
 /* change the trace filename */
 void eztrace_set_filename(char* name);
 
@@ -49,9 +70,9 @@ void eztrace_code1(uint32_t code, uint64_t arg1);
 void eztrace_code2(uint32_t code, uint64_t arg1, uint64_t arg2);
 void eztrace_code3(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3);
 void eztrace_code4(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3,
-                   uint64_t arg4);
+		   uint64_t arg4);
 void eztrace_code5(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3,
-                   uint64_t arg4, uint64_t arg5);
+		   uint64_t arg4, uint64_t arg5);
 void eztrace_code6(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3, uint64_t arg4, uint64_t arg5, uint64_t arg6);
 void eztrace_code7(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3, uint64_t arg4, uint64_t arg5, uint64_t arg6, uint64_t arg7);
 void eztrace_code8(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3, uint64_t arg4, uint64_t arg5, uint64_t arg6, uint64_t arg7, uint64_t arg8);
@@ -187,12 +208,11 @@ void set_recursion_shield_off();
 /* The PPTRACE_HIJACK_FUNCTION is an array that contain the list of functions that a module instrument
  * It is used by pptrace when insering probes in the binary as well as by eztrace.preload
  */
-/* the pptrace_hijack_function array is declared static so that each module has its own instance of the variable.
- */
-#define PPTRACE_START_INTERCEPT static char* PPTRACE_HIJACK_FUNCTION[] = {
 #define PPTRACE_INTERCEPT_FULL(function, repl, orig) #function " " #orig " " #repl,
 #define PPTRACE_INTERCEPT(function) #function " orig_" #function " " #function,
-#define PPTRACE_END_INTERCEPT  NULL };
+
+#define PPTRACE_START_INTERCEPT(module_name) char* PPTRACE_SYMBOL_LIST(module_name) [] __attribute__((visibility("protected"))) = {
+#define PPTRACE_END_INTERCEPT(module_name)  NULL }; extern char** PPTRACE_SYMBOL_EXTERNAL(module_name) __attribute__((alias(PPTRACE_SYMBOL_ALIAS(module_name))));
 
 #define ezt_is_in_launcher() ((getenv("TESTLAUNCHER") != NULL) && (strcmp(getenv("TESTLAUNCHER"), "1") == 0))
 
@@ -208,14 +228,14 @@ void set_recursion_shield_off();
     TREAT_ERROR();					\
   } while(0)
 
-#define DYNAMIC_INTERCEPT_ALL()					\
+#define DYNAMIC_INTERCEPT_ALL_MODULE(module_name)		\
   do {								\
     if (ezt_is_in_launcher())					\
       return;							\
     char __buff[1024];						\
     int __i; char *__j; char *__k; void **__sym;		\
-    for(__i = 0; PPTRACE_HIJACK_FUNCTION[__i] != NULL; __i++) { \
-      strncpy(__buff, PPTRACE_HIJACK_FUNCTION[__i], 1024);	\
+    for(__i = 0; PPTRACE_SYMBOL_LIST(module_name)[__i] != NULL; __i++) { \
+      strncpy(__buff, PPTRACE_SYMBOL_LIST(module_name)[__i], 1024);	\
       __buff[1023] = 0;						\
       __j = strchr(__buff, ' ');				\
       __k = strchr(__j+1, ' ');					\
@@ -225,8 +245,13 @@ void set_recursion_shield_off();
     }								\
   } while(0)
 
-#define START_INTERCEPT PPTRACE_START_INTERCEPT
-#define END_INTERCEPT PPTRACE_END_INTERCEPT
+#define START_INTERCEPT_MODULE(module_name) PPTRACE_START_INTERCEPT(module_name)
+#define END_INTERCEPT_MODULE(module_name) PPTRACE_END_INTERCEPT(module_name)
+
+#define DYNAMIC_INTERCEPT_ALL()	DYNAMIC_INTERCEPT_ALL_MODULE()
+#define START_INTERCEPT START_INTERCEPT_MODULE()
+#define END_INTERCEPT END_INTERCEPT_MODULE()
+
 #define INTERCEPT2(func, var) func " " #var " " func,
 
 #endif	/* __EZTRACE_H__ */
