@@ -50,10 +50,8 @@ static void __eztrace_set_buffer_size() {
 
 static char* __eztrace_get_filedir() {
   char* res = getenv("EZTRACE_TRACE_DIR");
-  int ret;
-  if (!res) {
-    ret = asprintf(&res, "/tmp");
-  }
+  if (!res)
+    asprintf(&res, "/tmp");
   return res;
 }
 
@@ -61,14 +59,14 @@ void eztrace_set_filename(char* name) {
   int total_size = strlen(__eztrace_get_filedir());
   total_size += strlen(getenv("USER"));
   total_size += strlen(name);
-  total_size += 3; 		/* add 3 chars ('/', '_', '\0') */
+  total_size += 3;		/* add 3 chars ('/', '_', '\0') */
 
   if(__ezt_trace.filename)
     free(__ezt_trace.filename);
   __ezt_trace.filename = malloc(total_size);
 
   sprintf(__ezt_trace.filename, "%s/%s_%s", __eztrace_get_filedir(), getenv("USER"),
-          name);
+	  name);
   litl_write_set_filename(__ezt_trace.litl_trace, __ezt_trace.filename);
 }
 
@@ -116,7 +114,7 @@ static char* get_function_name(char* symbol) {
     if (symbol[i] == '(') {
       begin = i;
       if (symbol[i + 1] == '+' || symbol[i + 1] == ')') {
-        return get_lib_name(symbol);
+	return get_lib_name(symbol);
       }
     }
     if (symbol[i] == ')') {
@@ -153,7 +151,7 @@ void eztrace_error_handler(int signo) {
   EZTRACE_EVENT2(EZTRACE_SIGNAL_RECEIVED, signo, nb_calls);
   for (i = 0; i < nb_calls; i++) {
     char* ptr = get_function_name(functions[i]);
-    litl_write_probe_raw(__ezt_trace.litl_trace, EZTRACE_CALLING_FUNCTION, strlen(ptr), ptr);
+    litl_write_probe_raw(__ezt_trace.litl_trace, EZTRACE_CALLING_FUNCTION, strlen(ptr), (void*)ptr);
   }
   free(functions);
 
@@ -180,7 +178,7 @@ void eztrace_signal_handler(int signo) {
 }
 
 /* when an alarm signal is received, check for sampling information */
-void __eztrace_alarm_sighandler(int signo){
+void __eztrace_alarm_sighandler(int signo __attribute__((unused))){
   ezt_sampling_check_callbacks();
 }
 
@@ -255,19 +253,15 @@ void eztrace_start() {
   __ezt_trace.debug_level = 0;
   __ezt_trace.buffer_size = (16 * 1024 * 1024); // 16MB
 
-  unsigned threadid;
-
   char* debug_mode = getenv("EZTRACE_DEBUG");
   if (debug_mode) {
       __ezt_trace.debug_level = atoi(debug_mode);
     EZT_PRINTF(0, "EZTrace Debug mode enabled (trace level: %d)\n",
-               __ezt_trace.debug_level);
+	       __ezt_trace.debug_level);
   }
 
   EZT_PRINTF(0, "Starting EZTrace... ");
-  threadid = CUR_TID;
-
-  __eztrace_set_buffer_size();
+   __eztrace_set_buffer_size();
 
   /* make sure eztrace_stop is called when the program stops */
   atexit(eztrace_stop);
@@ -312,7 +306,8 @@ void eztrace_stop_() {
 }
 
 void eztrace_stop() {
-  if(__ezt_trace.status >= ezt_trace_status_being_finalized)
+  if(__ezt_trace.status >= ezt_trace_status_being_finalized ||
+     __ezt_trace.status < ezt_trace_status_running)
     return;
   __ezt_trace.status = ezt_trace_status_being_finalized;
 
@@ -326,6 +321,63 @@ void eztrace_stop() {
   EZT_PRINTF(0, "Stopping EZTrace... saving trace  %s\n", __ezt_trace.filename);
 }
 
+void eztrace_silent_start() {
+  eztrace_start();
+  __ezt_trace.status = ezt_trace_status_paused;
+}
+
+void eztrace_pause() {
+  __ezt_trace.status = ezt_trace_status_paused;
+}
+
+void eztrace_resume() {
+  __ezt_trace.status = ezt_trace_status_running;
+}
+
+void eztrace_enter_event(char *name, enum ezt_color color) {
+  EZTRACE_PROTECT {
+    EZTRACE_PROTECT_ON();
+  switch (color) {
+   case EZTRACE_RED:
+     litl_write_probe_raw(__ezt_trace.litl_trace,
+			 EZTRACE_ENTER_EVENT_RED,
+			 strlen(name) + 1,
+			 (litl_data_t*) name);
+    break;
+  case EZTRACE_YELLOW:
+    litl_write_probe_raw(__ezt_trace.litl_trace,
+			 EZTRACE_ENTER_EVENT_YELLOW,
+			 strlen(name) + 1,
+			 (litl_data_t*) name);
+    break;
+      case EZTRACE_BLUE:
+    litl_write_probe_raw(__ezt_trace.litl_trace,
+			 EZTRACE_ENTER_EVENT_BLUE,
+			 strlen(name) + 1,
+			 (litl_data_t*) name);
+    break;
+      case EZTRACE_GREEN:
+    litl_write_probe_raw(__ezt_trace.litl_trace,
+			 EZTRACE_ENTER_EVENT_GREEN,
+			 strlen(name) + 1,
+			 (litl_data_t*) name);
+    break;
+      case EZTRACE_PINK:
+    litl_write_probe_raw(__ezt_trace.litl_trace,
+			 EZTRACE_ENTER_EVENT_PINK,
+			 strlen(name) + 1,
+			 (litl_data_t*) name);
+    break;
+  }
+  EZTRACE_PROTECT_OFF();
+  }
+}
+
+void eztrace_leave_event(char *name) {
+  EZTRACE_EVENT0(EZTRACE_LEAVE_EVENT);
+}
+
+
 void eztrace_generic(uint32_t code, int nbargs, ...) {
   int i;
   va_list args;
@@ -391,12 +443,12 @@ void eztrace_code3(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3) {
 }
 
 void eztrace_code4(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3,
-                   uint64_t arg4) {
+		   uint64_t arg4) {
   EZTRACE_EVENT4(code, arg1, arg2, arg3, arg4);
 }
 
 void eztrace_code5(uint32_t code, uint64_t arg1, uint64_t arg2, uint64_t arg3,
-                   uint64_t arg4, uint64_t arg5) {
+		   uint64_t arg4, uint64_t arg5) {
   EZTRACE_EVENT5(code, arg1, arg2, arg3, arg4, arg5);
 }
 
