@@ -83,8 +83,8 @@ void __print_mpi_requests() {
 
 void __print_p2p_message_header(FILE *stream) {
   fprintf(stream, "# src\tdest\tlen\ttag");
-  fprintf(stream, "\tIsend_tick\tSWait_tick\tWait_done_tick");
-  fprintf(stream, "\tIrecv_tick\tRWait_tick\tWait_done_tick");
+  fprintf(stream, "\tStart_Isend_tick\tStop_Isend_tick\tSWait_tick\tWait_done_tick");
+  fprintf(stream, "\tStart_Irecv_tick\tStop_Irecv_tick\tRWait_tick\tWait_done_tick");
   fprintf(stream, "\tSender_request\tReceiver_request");
   fprintf(stream, "\n");
 }
@@ -193,12 +193,10 @@ __mpi_find_mpi_req(int rank, app_ptr mpi_req, enum mpi_request_type req_type) {
   struct hierarchical_array *array = hierarchical_array_find(
       MPI_REQUEST_ID, GET_PROCESS_CONTAINER(rank_to_trace_id[rank]));
   assert(array);
-
   int index;
   struct mpi_request* req = NULL;
   for (index = (array->nb_items) - 1; index >= 0; index--) {
     req = ITH_ITEM(index, array);
-
     if ((req->ptr == mpi_req)
       && ((req_type == mpi_req_none) || (req->req_type == req_type))) {
       return req;
@@ -220,7 +218,6 @@ __mpi_find_pending_mpi_req(int rank, app_ptr mpi_req, enum mpi_request_type req_
 /* find the p2p message that corresponds to an mpi request */
 struct mpi_p2p_msg_t*
 __mpi_find_p2p_message_by_mpi_req(int rank, const struct mpi_request* request) {
-  FUNC_NAME;
   assert(request);
   assert(request->req_type != mpi_req_none);
 
@@ -314,7 +311,6 @@ __mpi_p2p_find_pending_comm(int src, int dest, int len __attribute__((unused)),
 
   struct mpi_p2p_msg_t* msg = NULL;
   struct ezt_list_token_t *token;
-  int i = 0;
   /* for each pending comm in the dest process, check if the message matches */
   ezt_list_foreach(&process_info->pending_comm[type], token)
   {
@@ -328,12 +324,10 @@ __mpi_p2p_find_pending_comm(int src, int dest, int len __attribute__((unused)),
       && ((msg->tag == tag) || (msg->tag == p_info->__MPI_ANY_TAG)
 	|| (tag == p_info->__MPI_ANY_TAG)) && (p_comm->status & mask_ok)
       && (!(p_comm->status & mask_not_ok))) {
-
       return p_comm;
     }
   }
   /* message not found */
-
   return NULL;
 }
 
@@ -460,7 +454,7 @@ static void __remove_message_from_pending_comm(struct mpi_p2p_msg_t* msg,
 		   EZTRACE_MPI_P2P_IRECV_ID, msg);
     msg->recver_thread_id = thread_id;
     msg->recver_request = mpi_req;
-    msg->times[start_recv] = start_time;
+    msg->times[start_irecv] = start_time;
 
     if (mpi_req) {
       mpi_req->status = mpi_req_status_pending;
@@ -481,11 +475,12 @@ static void __remove_message_from_pending_comm(struct mpi_p2p_msg_t* msg,
     struct mpi_pending_comm* pending_comm_outgoing = NULL;
     assert(pending_comm);
 
-    if (!(pending_comm->status & ISEND_DONE))
+    if (!(pending_comm->status & ISEND_DONE)) {
       /* the matching isend has not happened yet. This means there's a synchronisation problem
        * between the traces.
        */
       return NULL;
+    }
 
     /* update the status of the pending incoming comm */
     pending_comm->status |= RWAIT_DONE;
@@ -560,7 +555,7 @@ static void __remove_message_from_pending_comm(struct mpi_p2p_msg_t* msg,
 
     msg->sender_thread_id = thread_id;
     msg->sender_request = mpi_req;
-    msg->times[start_send] = start_time;
+    msg->times[start_isend] = start_time;
 
     if (mpi_req) {
       mpi_req->msg = msg;
