@@ -1,3 +1,6 @@
+! Copyright (C) CNRS, INRIA, Université Bordeaux 1, Télécom SudParis
+! See COPYING in top-level directory.
+
 subroutine MPI_COMM_SPAWN(CMD, ARGV, M, I, R, C, INTERCOMM, A, E)
 call MPIF_COMM_SPAWN(CMD, ARGV, M, I, R, C, INTERCOMM, A, E)
 return
@@ -33,6 +36,76 @@ call MPIF_Comm_rank(COMM, RANK, IERROR)
 return
 end
 
+subroutine MPI_Comm_create(COMM, GROUP, NEWCOMM, IERROR)
+call MPIF_Comm_create(COMM, GROUP, NEWCOMM, IERROR)
+return
+end
+
+subroutine MPI_Comm_create_group(COMM, GROUP, TAG, NEWCOMM, IERROR)
+call MPIF_Comm_create_group(COMM, GROUP, TAG, NEWCOMM, IERROR)
+return
+end
+
+subroutine MPI_Comm_split(COMM, COLOR, KEY, NEWCOMM, IERROR)
+call MPIF_Comm_split(COMM, COLOR, KEY, NEWCOMM, IERROR)
+return
+end
+
+subroutine MPI_Comm_dup(COMM, NEWCOMM, IERROR)
+call MPIF_Comm_dup(COMM, NEWCOMM, IERROR)
+return
+end
+
+subroutine MPI_Comm_dup_with_info(COMM, info, NEWCOMM, IERROR)
+call MPIF_Comm_dup_with_info(COMM, info, NEWCOMM, IERROR)
+return
+end
+
+subroutine MPI_COMM_SPLIT_TYPE(COMM, SPLIT_TYPE, KEY, INFO, NEWCOMM, IERROR)
+call MPIF_COMM_SPLIT_TYPE(COMM, SPLIT_TYPE, KEY, INFO, NEWCOMM, IERROR)
+return
+end
+
+subroutine MPI_Intercomm_create(LOCAL_COMM, LOCAL_LEADER, PEER_COMM, REMOTE_LEADER, TAG, NEWINTERCOMM, IERROR)
+call MPIF_Intercomm_create(LOCAL_COMM, LOCAL_LEADER, PEER_COMM, REMOTE_LEADER, TAG, NEWINTERCOMM, IERROR)
+return
+end
+
+subroutine MPI_INTERCOMM_MERGE(INTERCOMM, HIGH, NEWINTRACOMM, IERROR)
+call MPIF_INTERCOMM_MERGE(INTERCOMM, HIGH, NEWINTRACOMM, IERROR)
+return
+end
+
+subroutine MPI_CART_SUB(COMM, REMAIN_DIMS, COMM_NEW, IERROR)
+call MPIF_CART_SUB(COMM, REMAIN_DIMS, COMM_NEW, IERROR)
+return
+end
+
+subroutine MPI_CART_CREATE(COMM_OLD, NDIMS, DIMS, PERIODS, REORDER, COMM_CART, IERROR)
+call MPIF_CART_CREATE(COMM_OLD, NDIMS, DIMS, PERIODS, REORDER, COMM_CART, IERROR)
+return
+end
+
+subroutine MPI_GRAPH_CREATE(COMM_OLD, NNODES, INDEX, EDGES, REORDER, COMM_GRAPH, IERROR)
+call MPIF_GRAPH_CREATE(COMM_OLD, NNODES, INDEX, EDGES, REORDER, COMM_GRAPH, IERROR)
+return
+end
+
+subroutine MPI_DIST_GRAPH_CREATE(COMM_OLD, N, SOURCES, DEGREES, DESTINATIONS, WEIGHTS,&
+                INFO, REORDER, COMM_DIST_GRAPH, IERROR)
+call MPIF_DIST_GRAPH_CREATE(COMM_OLD, N, SOURCES, DEGREES, DESTINATIONS, WEIGHTS,&
+                INFO, REORDER, COMM_DIST_GRAPH, IERROR)
+return
+end
+
+subroutine MPI_DIST_GRAPH_CREATE_ADJACENT(COMM_OLD, INDEGREE, SOURCES, SOURCEWEIGHTS, &
+     OUTDEGREE, DESTINATIONS, DESTWEIGHTS, INFO, REORDER, COMM_DIST_GRAPH, IERROR)
+call  MPIF_DIST_GRAPH_CREATE_ADJACENT(COMM_OLD, INDEGREE, SOURCES, SOURCEWEIGHTS, &
+     OUTDEGREE, DESTINATIONS, DESTWEIGHTS, INFO, REORDER, COMM_DIST_GRAPH, IERROR)
+return
+end
+
+
 subroutine MPI_Send(BUF, COUNT, DATATYPE, DEST, TAG, COMM, IERROR)
 call MPIF_Send(BUF, COUNT, DATATYPE, DEST, TAG, COMM, IERROR)
 return
@@ -176,7 +249,7 @@ return
 end
 
 subroutine MPI_Scatterv(SBUF,SCNT,DSP,SDTYP,RBUF,RCNT,RTYP,R,C,E)
-call  MPIF_Scatterv(SBUF,SCNT,DSP,STYP,RBUF, RCNT, RTYP, R, C, E)
+call  MPIF_Scatterv(SBUF,SCNT,DSP,SDTYP,RBUF, RCNT, RTYP, R, C, E)
 return
 end
 
@@ -219,154 +292,3 @@ subroutine MPI_Scan(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
 call  MPIF_Scan(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
 return
 end
-
-
-
-
-subroutine MPI_IBarrier(COMM, REQ, IERROR)
-call MPIF_IBarrier(COMM, REQ, IERROR)
-return
-end
-
-subroutine MPI_IBCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, REQ, IERROR)
-call MPIF_IBCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, REQ, IERROR)
-return
-end
-
-subroutine MPI_IGather(SBUF,SCNT,STYPE,RBUF,RCNT, RTYPE, R, C, REQ, E)
-call MPIF_IGather(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C, REQ, E)
-return
-end
-
-subroutine MPI_IGatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,REQ,E)
-call MPIF_IGatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,REQ,E)
-return
-end
-
-subroutine MPI_IScatter(SBUF,SCNT,STYPE,RBUF,RCNT,RTYPE,R,C,REQ,E)
-call MPIF_IScatter(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C,REQ, E)
-return
-end
-
-subroutine MPI_IScatterv(SBUF,SCNT,DSP,SDTYP,RBUF,RCNT,RTYP,R,C,REQ,E)
-call  MPIF_IScatterv(SBUF,SCNT,DSP,STYP,RBUF, RCNT, RTYP, R, C, REQ,E)
-return
-end
-
-subroutine MPI_IAllgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, REQ, E)
-call MPIF_IAllgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, REQ, E)
-return
-end
-
-subroutine MPI_IAllgatherv(SB, SC, ST, RB, RC, D, RT, C, REQ,IERROR)
-call MPIF_IAllgatherv(SB, SC, ST, RB, RC, D, RT, C, REQ,IERROR)
-return
-end
-
-subroutine MPI_IAlltoall(SB, SC, ST, RB, RC, RT, COMM, REQ,IERROR)
-call MPIF_IAlltoall(SB, SC, ST, RB, RC, RT, COMM, REQ,IERROR)
-return
-end
-
-subroutine MPI_IAlltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, REQ,ERROR)
-call MPIF_IAlltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, REQ,ERROR)
-return
-end
-
-subroutine MPI_IReduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, REQ,IERROR)
-call MPIF_IReduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, REQ,IERROR)
-return
-end
-
-subroutine MPI_IAllreduce(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
-call MPIF_IAllreduce(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
-return
-end
-
-subroutine MPI_IReduce_scatter(SBUF, RBUF, RCNT, D, OP, C, REQ,IERROR)
-call MPIF_IReduce_scatter(SBUF, RBUF, RCNT, D, OP, C, REQ,IERROR)
-return
-end
-
-subroutine MPI_IScan(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
-call  MPIF_IScan(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
-return
-end
-
-
-
-subroutine MPI_Send_init(B, C, T, D, TAG, COMM, R, IERROR)
-call MPIF_Send_init(B, C, T, D, TAG, COMM, R, IERROR)
-return
-end
-
-subroutine MPI_BSend_init(B, C, T, D, TAG, COMM, R, IERROR)
-call MPIF_BSend_init(B, C, T, D, TAG, COMM, R, IERROR)
-return
-end
-
-subroutine MPI_RSend_init(B, C, T, D, TAG, COMM, R, IERROR)
-call MPIF_RSend_init(B, C, T, D, TAG, COMM, R, IERROR)
-return
-end
-
-subroutine MPI_SSend_init(B, C, T, D, TAG, COMM, R, IERROR)
-call MPIF_SSend_init(B, C, T, D, TAG, COMM, R, IERROR)
-return
-end
-
-subroutine MPI_Recv_init(B, C, T, S, TAG, COMM, R, IERROR)
-call MPIF_Recv_init(B, C, T, S, TAG, COMM, R, IERROR)
-return
-end
-
-subroutine MPI_Start(R, IERROR)
-call MPIF_Start(R, IERROR)
-return
-end
-
-subroutine MPI_Startall(C, R, IERROR)
-call MPIF_Startall(C, R, IERROR)
-return
-end
-
-
-subroutine MPI_Comm_create(comm, group, newcomm, IERROR)
-call MPIF_Comm_create(comm, group, newcomm, IERROR)
-return
-end
-
-subroutine MPI_Comm_split(comm, color, key, newcomm, IERROR)
-call MPIF_Comm_split(comm, color, key, newcomm, IERROR)
-return
-end
-
-subroutine MPI_Comm_dup(comm, newcomm, IERROR)
-call MPIF_Comm_dup(comm, newcomm, IERROR)
-return
-end
-
-subroutine MPI_Intercomm_create(local_comm, local_leader, peer_comm, remote_leader, tag, newintercomm, IERROR)
-call MPIF_Intercomm_create(local_comm, local_leader, peer_comm, remote_leader, tag, newintercomm, IERROR)
-return
-end
-
-subroutine MPI_Intercomm_merge(intercomm, high, newintracomm, IERROR)
-call MPIF_Intercomm_merge(intercomm, high, newintracomm, IERROR)
-return
-end
-
-subroutine MPI_Cart_sub(old_comm, belongs, new_comm, IERROR)
-call MPIF_Cart_sub(old_comm, belongs, new_comm, IERROR)
-return
-end
-
-subroutine MPI_Cart_create(comm_old, ndims, dims, periods, reorder, comm_cart, IERROR)
-call MPIF_Cart_create(comm_old, ndims, dims, periods, reorder, comm_cart, IERROR)
-return
-end
-
-subroutine MPI_Graph_create(comm_old, nnodes, index, edges, reorder, comm_graph, IERROR)
-call MPIF_Graph_create(comm_old, nnodes, index, edges, reorder, comm_graph, IERROR)
-return
-end
