@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,31 +21,27 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-static void MPI_Barrier_prolog (MPI_Comm c)
-{
+static void MPI_Barrier_prolog(MPI_Comm c) {
   int rank = -1;
   int size = -1;
   libMPI_Comm_size(c, &size);
   libMPI_Comm_rank(c, &rank);
-  EZTRACE_EVENT3 (FUT_MPI_START_BARRIER, c, rank, size);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_START_BARRIER, (app_ptr)c, rank, size);
 }
 
-static int MPI_Barrier_core (MPI_Comm c)
-{
+static int MPI_Barrier_core(MPI_Comm c) {
   return libMPI_Barrier(c);
 }
 
-static void MPI_Barrier_epilog (MPI_Comm c)
-{
+static void MPI_Barrier_epilog(MPI_Comm c) {
   int rank = -1;
   int size = -1;
   libMPI_Comm_size(c, &size);
   libMPI_Comm_rank(c, &rank);
-  EZTRACE_EVENT3 (FUT_MPI_STOP_BARRIER, c, rank, size);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_BARRIER, (app_ptr)c, rank, size);
 }
 
-int MPI_Barrier (MPI_Comm c)
-{
+int MPI_Barrier(MPI_Comm c) {
   FUNCTION_ENTRY;
 
   MPI_Barrier_prolog(c);
@@ -55,8 +51,8 @@ int MPI_Barrier (MPI_Comm c)
   return ret;
 }
 
-void mpif_barrier_(MPI_Fint *c, int *error)
-{
+void mpif_barrier_(MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Barrier_prolog(c_comm);
   *error = MPI_Barrier_core(c_comm);
