@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,30 +21,24 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-static void MPI_Bcast_prolog(void *buffer __attribute__((unused)),
-			     int count,
-			     MPI_Datatype datatype,
-			     int root,
-			     MPI_Comm comm)
-{
+static void MPI_Bcast_prolog(void *buffer __attribute__((unused)), int count,
+                             MPI_Datatype datatype, int root, MPI_Comm comm) {
   int rank = -1;
   int size = -1;
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
-  int msize;
-  MPI_Type_size(datatype, &msize);
-  EZTRACE_EVENT5(FUT_MPI_START_BCast, comm, size, rank, msize*count, root);
+  EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_START_BCast, (app_ptr)comm, size, rank, root);
 }
 
-static int MPI_Bcast_core(void *buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm)
-{
+static int MPI_Bcast_core(void *buffer, int count, MPI_Datatype datatype,
+                          int root, MPI_Comm comm) {
   return libMPI_Bcast(buffer, count, datatype, root, comm);
 }
 
 static void MPI_Bcast_epilog(void *buffer __attribute__((unused)),
 			     int count __attribute__((unused)),
 			     MPI_Datatype datatype,
-			     int root,
+			     int __attribute__((unused)) root,
 			     MPI_Comm comm)
 {
   int rank = -1;
@@ -52,13 +46,11 @@ static void MPI_Bcast_epilog(void *buffer __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int msize;
-  MPI_Type_size(datatype, &msize);
-  EZTRACE_EVENT4(FUT_MPI_STOP_BCast, comm, size, rank, msize*count);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_BCast, (app_ptr)comm, size, rank);
 }
 
-int MPI_Bcast(void *buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm)
-{
+int MPI_Bcast(void *buffer, int count, MPI_Datatype datatype, int root,
+              MPI_Comm comm) {
   FUNCTION_ENTRY;
   MPI_Bcast_prolog(buffer, count, datatype, root, comm);
   int ret = MPI_Bcast_core(buffer, count, datatype, root, comm);
@@ -66,9 +58,9 @@ int MPI_Bcast(void *buffer, int count, MPI_Datatype datatype, int root, MPI_Comm
   return ret;
 }
 
-void mpif_bcast_(void *buf, int *count, MPI_Fint *d,
-		 int *root, MPI_Fint *c, int *error)
-{
+void mpif_bcast_(void *buf, int *count, MPI_Fint *d, int *root, MPI_Fint *c,
+                 int *error) {
+  FUNCTION_ENTRY;
   MPI_Datatype c_type = MPI_Type_f2c(*d);
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Bcast_prolog(buf, *count, c_type, *root, c_comm);
