@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -35,19 +35,15 @@ static void MPI_Gather_prolog(CONST void *sendbuf __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int ssize, rsize;
-  MPI_Type_size(sendtype, &ssize);
-  MPI_Type_size(recvtype, &rsize);
-
-  EZTRACE_EVENT5(FUT_MPI_START_Gather, comm, size, rank, ssize*sendcnt, root);
-
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_START_Gather, (app_ptr)comm, size, rank);
 }
 
-static int MPI_Gather_core(CONST void *sendbuf, int sendcnt, MPI_Datatype sendtype,
-			   void *recvbuf, int recvcount, MPI_Datatype recvtype,
-			   int root, MPI_Comm comm)
+static int MPI_Gather_core(CONST void *sendbuf, int sendcnt,
+                           MPI_Datatype sendtype, void *recvbuf, int recvcount,
+                           MPI_Datatype recvtype, int root, MPI_Comm comm)
 {
-  return libMPI_Gather(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype, root, comm);
+  return libMPI_Gather(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype,
+                       root, comm);
 }
 
 static void MPI_Gather_epilog(CONST void *sendbuf __attribute__((unused)),
@@ -64,35 +60,36 @@ static void MPI_Gather_epilog(CONST void *sendbuf __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int ssize, rsize;
-  MPI_Type_size(sendtype, &ssize);
-  MPI_Type_size(recvtype, &rsize);
-  EZTRACE_EVENT4(FUT_MPI_STOP_Gather, comm, size, rank, ssize*sendcnt);
-
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_Gather, (app_ptr)comm, size, rank);
 }
 
-
 int MPI_Gather(CONST void *sendbuf, int sendcnt, MPI_Datatype sendtype,
 	       void *recvbuf, int recvcount, MPI_Datatype recvtype,
 	       int root, MPI_Comm comm)
 {
   FUNCTION_ENTRY;
-  MPI_Gather_prolog(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype, root, comm);
-  int ret = MPI_Gather_core(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype, root, comm);
-  MPI_Gather_epilog(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype, root, comm);
+  MPI_Gather_prolog(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype,
+                    root, comm);
+  int ret = MPI_Gather_core(sendbuf, sendcnt, sendtype, recvbuf, recvcount,
+                            recvtype, root, comm);
+  MPI_Gather_epilog(sendbuf, sendcnt, sendtype, recvbuf, recvcount, recvtype,
+                    root, comm);
   return ret;
 }
 
-
-void mpif_gather_(void *sbuf, int *scount, MPI_Fint *sd,
-		  void *rbuf, int *rcount, MPI_Fint *rd,
-		  int *root, MPI_Fint *c, int *error)
-{
+void mpif_gather_(void *sbuf, int *scount, MPI_Fint *sd, void *rbuf,
+                  int *rcount, MPI_Fint *rd, int *root, MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Datatype c_stype = MPI_Type_f2c(*sd);
   MPI_Datatype c_rtype = MPI_Type_f2c(*rd);
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
+  void *c_sbuf = CHECK_MPI_IN_PLACE(sbuf);
+  void *c_rbuf = CHECK_MPI_IN_PLACE(rbuf);
 
-  MPI_Gather_prolog(sbuf, *scount, c_stype, rbuf, *rcount, c_rtype, *root, c_comm);
-  *error = MPI_Gather_core(sbuf, *scount, c_stype, rbuf, *rcount, c_rtype, *root, c_comm);
-  MPI_Gather_epilog(sbuf, *scount, c_stype, rbuf, *rcount, c_rtype, *root, c_comm);
+  MPI_Gather_prolog(c_sbuf, *scount, c_stype, c_rbuf, *rcount, c_rtype, *root,
+                    c_comm);
+  *error = MPI_Gather_core(c_sbuf, *scount, c_stype, c_rbuf, *rcount, c_rtype,
+                           *root, c_comm);
+  MPI_Gather_epilog(c_sbuf, *scount, c_stype, c_rbuf, *rcount, c_rtype, *root,
+                    c_comm);
 }
