@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -36,19 +36,16 @@ static void MPI_Gatherv_prolog(CONST void *sendbuf __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int ssize, rsize;
-  MPI_Type_size(sendtype, &ssize);
-  MPI_Type_size(recvtype, &rsize);
-
-  EZTRACE_EVENT5(FUT_MPI_START_Gatherv, comm, size, rank, ssize*sendcnt, root);
-
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_START_Gatherv, (app_ptr)comm, size, rank);
 }
 
-static int MPI_Gatherv_core(CONST void *sendbuf, int sendcnt, MPI_Datatype sendtype,
-			    void *recvbuf, CONST int *recvcnts, CONST int *displs,
-			    MPI_Datatype recvtype, int root, MPI_Comm comm)
+static int MPI_Gatherv_core(CONST void *sendbuf, int sendcnt,
+                            MPI_Datatype sendtype, void *recvbuf,
+                            CONST int *recvcnts, CONST int *displs,
+                            MPI_Datatype recvtype, int root, MPI_Comm comm)
 {
-  return libMPI_Gatherv(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs, recvtype, root, comm);
+  return libMPI_Gatherv(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs,
+                        recvtype, root, comm);
 }
 
 static void MPI_Gatherv_epilog(CONST void *sendbuf __attribute__((unused)),
@@ -66,11 +63,7 @@ static void MPI_Gatherv_epilog(CONST void *sendbuf __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int ssize, rsize;
-  MPI_Type_size(sendtype, &ssize);
-  MPI_Type_size(recvtype, &rsize);
-
-  EZTRACE_EVENT3(FUT_MPI_STOP_Gatherv, comm, size, rank);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_Gatherv, (app_ptr)comm, size, rank);
 }
 
 int MPI_Gatherv(CONST void *sendbuf, int sendcnt, MPI_Datatype sendtype,
@@ -79,24 +72,30 @@ int MPI_Gatherv(CONST void *sendbuf, int sendcnt, MPI_Datatype sendtype,
 {
   FUNCTION_ENTRY;
 
-  MPI_Gatherv_prolog(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs, recvtype, root, comm);
-  int ret = MPI_Gatherv_core(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs, recvtype, root, comm);
-  MPI_Gatherv_epilog(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs, recvtype, root, comm);
+  MPI_Gatherv_prolog(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs,
+                     recvtype, root, comm);
+  int ret = MPI_Gatherv_core(sendbuf, sendcnt, sendtype, recvbuf, recvcnts,
+                             displs, recvtype, root, comm);
+  MPI_Gatherv_epilog(sendbuf, sendcnt, sendtype, recvbuf, recvcnts, displs,
+                     recvtype, root, comm);
 
   return ret;
 }
 
-
-void mpif_gatherv_(void *sbuf, int *scount, MPI_Fint *sd,
-		   void *rbuf, int *rcount, int *displs,
-		   MPI_Fint *rd, int *root, MPI_Fint *c, int *error)
-{
+void mpif_gatherv_(void *sbuf, int *scount, MPI_Fint *sd, void *rbuf,
+                   int *rcount, int *displs, MPI_Fint *rd, int *root,
+                   MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Datatype c_stype = MPI_Type_f2c(*sd);
   MPI_Datatype c_rtype = MPI_Type_f2c(*rd);
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
+  void *c_sbuf = CHECK_MPI_IN_PLACE(sbuf);
+  void *c_rbuf = CHECK_MPI_IN_PLACE(rbuf);
 
-  MPI_Gatherv_prolog(sbuf, *scount, c_stype, rbuf, rcount, displs, c_rtype, *root, c_comm);
-  *error = MPI_Gatherv_core(sbuf, *scount, c_stype, rbuf, rcount,
-			    displs, c_rtype, *root, c_comm);
-  MPI_Gatherv_epilog(sbuf, *scount, c_stype, rbuf, rcount, displs, c_rtype, *root, c_comm);
+  MPI_Gatherv_prolog(c_sbuf, *scount, c_stype, c_rbuf, rcount, displs, c_rtype,
+                     *root, c_comm);
+  *error = MPI_Gatherv_core(c_sbuf, *scount, c_stype, c_rbuf, rcount, displs,
+                            c_rtype, *root, c_comm);
+  MPI_Gatherv_epilog(c_sbuf, *scount, c_stype, c_rbuf, rcount, displs, c_rtype,
+                     *root, c_comm);
 }
