@@ -22,6 +22,27 @@
 #include "eztrace.h"
 
 #ifdef USE_MPI3
+static void MPI_Iscatterv_prolog(CONST void *sendbuf __attribute__((unused)),
+				 CONST int *sendcnts __attribute__((unused)),
+				 CONST int *displs __attribute__((unused)),
+				 MPI_Datatype sendtype __attribute__((unused)),
+				 void *recvbuf __attribute__((unused)),
+				 int recvcnt __attribute__((unused)),
+				 MPI_Datatype recvtype __attribute__((unused)),
+				 int root __attribute__((unused)),
+				 MPI_Comm comm,
+				 MPI_Request *r)
+{
+  int rank = -1;
+  int size = -1;
+  libMPI_Comm_size(comm, &size);
+  libMPI_Comm_rank(comm, &rank);
+  int ssize;
+  MPI_Type_size(sendtype, &ssize);
+
+  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_ISCATTERV, (app_ptr)comm, size, rank, (ssize*(*sendcnts)), (app_ptr)r);
+}
+
 static int MPI_Iscatterv_core(CONST void *sendbuf,
 			      CONST int *sendcnts,
 			      CONST int *displs,
@@ -44,17 +65,9 @@ static void MPI_Iscatterv_epilog(CONST void *sendbuf __attribute__((unused)),
 				 int recvcnt __attribute__((unused)),
 				 MPI_Datatype recvtype __attribute__((unused)),
 				 int root __attribute__((unused)),
-				 MPI_Comm comm,
-				 MPI_Request *r)
-{
-  int rank = -1;
-  int size = -1;
-  libMPI_Comm_size(comm, &size);
-  libMPI_Comm_rank(comm, &rank);
-  int ssize, rsize;
-  MPI_Type_size(sendtype, &ssize);
-
-  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_ISCATTERV, (app_ptr)comm, size, rank, (ssize*(*sendcnts)), (app_ptr)r);
+				 MPI_Comm comm __attribute__((unused)),
+				 MPI_Request *r) {
+  EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_STOP_ISCATTERV, (app_ptr)r);
 }
 
 
@@ -70,6 +83,7 @@ int MPI_Iscatterv(CONST void *sendbuf,
 		  MPI_Request *r)
 {
   FUNCTION_ENTRY;
+  MPI_Iscatterv_prolog(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm, r);
   int ret = MPI_Iscatterv_core(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm, r);
   MPI_Iscatterv_epilog(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm, r);
   return ret;
@@ -86,13 +100,16 @@ void mpif_iscatterv_(void *sbuf, int *scount, int *displs, MPI_Fint *sd,
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Request c_req = MPI_Request_f2c(*r);
 
+  MPI_Iscatterv_prolog(sbuf, scount, displs, c_stype,
+		       rbuf, *rcount, c_rtype,
+		       *root, c_comm, r);
   *error = MPI_Iscatterv_core(sbuf, scount, displs, c_stype,
 			      rbuf, *rcount, c_rtype,
 			      *root, c_comm, &c_req);
 
   *r= MPI_Request_c2f(c_req);
   MPI_Iscatterv_epilog(sbuf, scount, displs, c_stype,
-		      rbuf, *rcount, c_rtype,
+		       rbuf, *rcount, c_rtype,
 		      *root, c_comm, r);
 }
 #endif
