@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,41 +21,32 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
-static void MPI_Recv_prolog(void *buf __attribute__((unused)),
-			    int count,
-			    MPI_Datatype datatype,
-			    int source,
-			    int tag,
-			    MPI_Comm comm,
-			    MPI_Status *status __attribute__((unused)))
-{
+static void MPI_Recv_prolog(void *buf __attribute__((unused)), int count,
+                            MPI_Datatype datatype, int source, int tag,
+                            MPI_Comm comm,
+                            MPI_Status *status __attribute__((unused))) {
   int size;
   MPI_Type_size(datatype, &size);
-  EZTRACE_EVENT4 (FUT_MPI_START_RECV, count*size, source, tag, comm);
+      EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_START_RECV, count*size, source, tag, (app_ptr) comm);
 }
 
-static int MPI_Recv_core(void *buf, int count, MPI_Datatype datatype, int source, int tag, MPI_Comm comm, MPI_Status *status)
-{
+static int MPI_Recv_core(void *buf, int count, MPI_Datatype datatype,
+                         int source, int tag, MPI_Comm comm, MPI_Status *status) {
   return libMPI_Recv(buf, count, datatype, source, tag, comm, status);
 }
 
-static void MPI_Recv_epilog(void *buf __attribute__((unused)),
-			    int count,
-			    MPI_Datatype datatype,
-			    int source,
-			    int tag,
-			    MPI_Comm comm,
-			    MPI_Status *status __attribute__((unused)))
-{
+static void MPI_Recv_epilog(void *buf __attribute__((unused)), int count,
+                            MPI_Datatype datatype, int source, int tag,
+                            MPI_Comm comm,
+                            MPI_Status *status __attribute__((unused))) {
   int size;
+    EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_STOP_RECV, count*size, source, tag, (app_ptr)comm);
   MPI_Type_size(datatype, &size);
-  EZTRACE_EVENT4 (FUT_MPI_STOP_RECV, count*size, source, tag, comm);
 }
 
 /* C function */
-int MPI_Recv(void *buf, int count, MPI_Datatype datatype, int source, int tag, MPI_Comm comm, MPI_Status *status)
-{
+int MPI_Recv(void *buf, int count, MPI_Datatype datatype, int source, int tag,
+             MPI_Comm comm, MPI_Status *status) {
   FUNCTION_ENTRY;
   MPI_Recv_prolog(buf, count, datatype, source, tag, comm, status);
   int ret = MPI_Recv_core(buf, count, datatype, source, tag, comm, status);
@@ -64,10 +55,9 @@ int MPI_Recv(void *buf, int count, MPI_Datatype datatype, int source, int tag, M
 }
 
 /* fortran function */
-void mpif_recv_(void *buf, int *count, MPI_Fint *d,
-		int *src, int *tag, MPI_Fint *c,
-		MPI_Fint *s, int *error)
-{
+void mpif_recv_(void *buf, int *count, MPI_Fint *d, int *src, int *tag,
+                MPI_Fint *c, MPI_Fint *s, int *error) {
+  FUNCTION_ENTRY;
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Datatype c_type = MPI_Type_f2c(*d);
   MPI_Status c_status;
