@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,7 +21,6 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
 static void MPI_Reduce_scatter_prolog (CONST void *sendbuf __attribute__((unused)),
 				       void *recvbuf __attribute__((unused)),
 				       CONST int *recvcnts __attribute__((unused)),
@@ -37,13 +36,14 @@ static void MPI_Reduce_scatter_prolog (CONST void *sendbuf __attribute__((unused
   int len;
   MPI_Type_size(datatype, &len);
 
-  EZTRACE_EVENT3(FUT_MPI_START_Reduce_scatter, comm, size, rank);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_START_Reduce_scatter, (app_ptr)comm, size, rank);
 }
 
-static int MPI_Reduce_scatter_core (CONST void *sendbuf, void *recvbuf, CONST int *recvcnts,
-				    MPI_Datatype datatype, MPI_Op op, MPI_Comm comm)
+static int MPI_Reduce_scatter_core(CONST void *sendbuf, void *recvbuf,
+                                   CONST int *recvcnts, MPI_Datatype datatype,
+                                   MPI_Op op, MPI_Comm comm)
 {
-  return libMPI_Reduce_scatter (sendbuf, recvbuf, recvcnts, datatype, op, comm);
+  return libMPI_Reduce_scatter(sendbuf, recvbuf, recvcnts, datatype, op, comm);
 }
 
 static void MPI_Reduce_scatter_epilog (CONST void *sendbuf __attribute__((unused)),
@@ -61,30 +61,31 @@ static void MPI_Reduce_scatter_epilog (CONST void *sendbuf __attribute__((unused
   int len;
   MPI_Type_size(datatype, &len);
 
-  EZTRACE_EVENT3(FUT_MPI_STOP_Reduce_scatter, comm, size, rank);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_Reduce_scatter, (app_ptr)comm, size, rank);
 }
 
-
-int MPI_Reduce_scatter (CONST void *sendbuf, void *recvbuf, CONST int *recvcnts,
-			MPI_Datatype datatype, MPI_Op op, MPI_Comm comm)
+int MPI_Reduce_scatter(CONST void *sendbuf, void *recvbuf, CONST int *recvcnts,
+                       MPI_Datatype datatype, MPI_Op op, MPI_Comm comm)
 {
   FUNCTION_ENTRY;
 
-  MPI_Reduce_scatter_prolog (sendbuf, recvbuf, recvcnts, datatype, op, comm);
-  int ret = MPI_Reduce_scatter_core (sendbuf, recvbuf, recvcnts, datatype, op, comm);
-  MPI_Reduce_scatter_epilog (sendbuf, recvbuf, recvcnts, datatype, op, comm);
+  MPI_Reduce_scatter_prolog(sendbuf, recvbuf, recvcnts, datatype, op, comm);
+  int ret = MPI_Reduce_scatter_core(sendbuf, recvbuf, recvcnts, datatype, op,
+                                    comm);
+  MPI_Reduce_scatter_epilog(sendbuf, recvbuf, recvcnts, datatype, op, comm);
   return ret;
 }
 
-void mpif_reduce_scatter_(void *sbuf, void *rbuf, int *rcount,
-			  MPI_Fint *d, MPI_Fint *op,
-			  MPI_Fint *c, int *error)
-{
+void mpif_reduce_scatter_(void *sbuf, void *rbuf, int *rcount, MPI_Fint *d,
+                          MPI_Fint *op, MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Datatype c_type = MPI_Type_f2c(*d);
   MPI_Op c_op = MPI_Op_f2c(*op);
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
+  void *c_sbuf = CHECK_MPI_IN_PLACE(sbuf);
+  void *c_rbuf = CHECK_MPI_IN_PLACE(rbuf);
 
-  MPI_Reduce_scatter_prolog(sbuf, rbuf, rcount, c_type, c_op, c_comm);
-  *error = MPI_Reduce_scatter_core(sbuf, rbuf, rcount, c_type, c_op, c_comm);
-  MPI_Reduce_scatter_epilog(sbuf, rbuf, rcount, c_type, c_op, c_comm);
+  MPI_Reduce_scatter_prolog(c_sbuf, c_rbuf, rcount, c_type, c_op, c_comm);
+  *error = MPI_Reduce_scatter_core(c_sbuf, c_rbuf, rcount, c_type, c_op, c_comm);
+  MPI_Reduce_scatter_epilog(c_sbuf, c_rbuf, rcount, c_type, c_op, c_comm);
 }
