@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -30,10 +30,11 @@ static void MPI_Rsend_prolog (CONST void* buf __attribute__((unused)),
 {
   int size;
   MPI_Type_size(datatype, &size);
-  EZTRACE_EVENT4 (FUT_MPI_START_RSEND, count*size, dest, tag, comm);
+    EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_START_RSEND, count*size, dest, tag, (app_ptr)comm);
 }
 
-static int MPI_Rsend_core (CONST void* buf, int count, MPI_Datatype datatype, int dest, int tag, MPI_Comm comm)
+static int MPI_Rsend_core(CONST void* buf, int count, MPI_Datatype datatype,
+                          int dest, int tag, MPI_Comm comm)
 {
   return libMPI_Rsend(buf, count, datatype, dest, tag, comm);
 }
@@ -45,11 +46,11 @@ static void MPI_Rsend_epilog (CONST void* buf __attribute__((unused)),
 			      int tag,
 			      MPI_Comm comm)
 {
-  EZTRACE_EVENT3 (FUT_MPI_STOP_RSEND, dest, tag, comm);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_RSEND, dest, tag, (app_ptr)comm);
 }
 
-
-int MPI_Rsend (CONST void* buf, int count, MPI_Datatype datatype, int dest, int tag, MPI_Comm comm)
+int MPI_Rsend(CONST void* buf, int count, MPI_Datatype datatype, int dest,
+              int tag, MPI_Comm comm)
 {
   FUNCTION_ENTRY;
   MPI_Rsend_prolog(buf, count, datatype, dest, tag, comm);
@@ -58,10 +59,9 @@ int MPI_Rsend (CONST void* buf, int count, MPI_Datatype datatype, int dest, int
   return ret;
 }
 
-
-void mpif_rsend_(void *buf, int *count, MPI_Fint *d, int *dest,
-		 int *tag, MPI_Fint *c, int *error)
-{
+void mpif_rsend_(void *buf, int *count, MPI_Fint *d, int *dest, int *tag,
+                 MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Datatype c_type = MPI_Type_f2c(*d);
 
