@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,34 +21,30 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
-static void MPI_Wait_prolog(MPI_Fint *req, MPI_Status *s __attribute__((unused)))
-{
-  EZTRACE_EVENT1(FUT_MPI_START_WAIT, req);
+static void MPI_Wait_prolog(MPI_Fint *req,
+                            MPI_Status *s __attribute__((unused))) {
+  EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_START_WAIT, (app_ptr)req);
 }
 
-static int MPI_Wait_core(MPI_Request *req, MPI_Status *s)
-{
+static int MPI_Wait_core(MPI_Request *req, MPI_Status *s) {
   return libMPI_Wait(req, s);
 }
 
-static void MPI_Wait_epilog(MPI_Fint *req, MPI_Status *s __attribute__((unused)))
-{
-  EZTRACE_EVENT1(FUT_MPI_STOP_WAIT, req);
+static void MPI_Wait_epilog(MPI_Fint *req,
+                            MPI_Status *s __attribute__((unused))) {
+  EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_STOP_WAIT, (app_ptr)req);
 }
 
-
-int MPI_Wait(MPI_Request *req, MPI_Status *s)
-{
+int MPI_Wait(MPI_Request *req, MPI_Status *s) {
   FUNCTION_ENTRY;
-  MPI_Wait_prolog((MPI_Fint*)req, s);
+  MPI_Wait_prolog((MPI_Fint*) req, s);
   int ret = MPI_Wait_core(req, s);
   MPI_Wait_epilog((MPI_Fint*) req, s);
   return ret;
 }
 
-void mpif_wait_(MPI_Fint *r, MPI_Fint *s, int *error)
-{
+void mpif_wait_(MPI_Fint *r, MPI_Fint *s, int *error) {
+  FUNCTION_ENTRY;
   MPI_Request c_req = MPI_Request_f2c(*r);
   MPI_Status c_status;
   MPI_Wait_prolog(r, &c_status);
@@ -56,4 +52,3 @@ void mpif_wait_(MPI_Fint *r, MPI_Fint *s, int *error)
   MPI_Status_c2f(&c_status, s);
   MPI_Wait_epilog(r, &c_status);
 }
-
